/*
 * Copyright 2021 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.android.fhir.datacapture.contrib.views.barcode.mlkit.md.barcodedetection

import android.graphics.Canvas
import android.graphics.Path
import com.google.android.fhir.datacapture.contrib.views.barcode.mlkit.md.camera.GraphicOverlay
import com.google.android.fhir.datacapture.contrib.views.barcode.mlkit.md.settings.PreferenceUtils
import com.google.mlkit.vision.barcode.Barcode

/** Guides user to move camera closer to confirm the detected barcode. */
internal class BarcodeConfirmingGraphic(overlay: GraphicOverlay, private val barcode: Barcode) :
  BarcodeGraphicBase(overlay) {

  override fun draw(canvas: Canvas) {
    super.draw(canvas)

    // Draws a highlighted path to indicate the current progress to meet size requirement.
    val sizeProgress = PreferenceUtils.getProgressToMeetBarcodeSizeRequirement(overlay, barcode)
    val path = Path()
    if (sizeProgress > 0.95f) {
      // To have a completed path with all corners rounded.
      path.moveTo(boxRect.left, boxRect.top)
      path.lineTo(boxRect.right, boxRect.top)
      path.lineTo(boxRect.right, boxRect.bottom)
      path.lineTo(boxRect.left, boxRect.bottom)
      path.close()
    } else {
      path.moveTo(boxRect.left, boxRect.top + boxRect.height() * sizeProgress)
      path.lineTo(boxRect.left, boxRect.top)
      path.lineTo(boxRect.left + boxRect.width() * sizeProgress, boxRect.top)

      path.moveTo(boxRect.right, boxRect.bottom - boxRect.height() * sizeProgress)
      path.lineTo(boxRect.right, boxRect.bottom)
      path.lineTo(boxRect.right - boxRect.width() * sizeProgress, boxRect.bottom)
    }
    canvas.drawPath(path, pathPaint)
  }
}
